Rename ModuleBuildPath -> ModuleBuildStack. Thanks, Dmitri!


git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@169045 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Frontend/CompilerInstance.cpp b/lib/Frontend/CompilerInstance.cpp
index 150f995..d481ebf 100644
--- a/lib/Frontend/CompilerInstance.cpp
+++ b/lib/Frontend/CompilerInstance.cpp
@@ -859,14 +859,14 @@
                              /*ShouldOwnClient=*/true,
                              /*ShouldCloneClient=*/true);
 
   // Note that this module is part of the module build path, so that we
   // can detect cycles in the module graph.
   Instance.createFileManager(); // FIXME: Adopt file manager from importer?
   Instance.createSourceManager(Instance.getFileManager());
   SourceManager &SourceMgr = Instance.getSourceManager();
-  SourceMgr.setModuleBuildPath(
-    ImportingInstance.getSourceManager().getModuleBuildPath());
-  SourceMgr.appendModuleBuildPath(Module->getTopLevelModuleName(),
+  SourceMgr.setModuleBuildStack(
+    ImportingInstance.getSourceManager().getModuleBuildStack());
+  SourceMgr.pushModuleBuildStack(Module->getTopLevelModuleName(),
     FullSourceLoc(ImportLoc, ImportingInstance.getSourceManager()));
 
 
@@ -947,8 +947,8 @@
       // build the module.
 
       // Check whether there is a cycle in the module graph.
-      ModuleBuildPath Path = getSourceManager().getModuleBuildPath();
-      ModuleBuildPath::iterator Pos = Path.begin(), PosEnd = Path.end();
+      ModuleBuildStack Path = getSourceManager().getModuleBuildStack();
+      ModuleBuildStack::iterator Pos = Path.begin(), PosEnd = Path.end();
       for (; Pos != PosEnd; ++Pos) {
         if (Pos->first == ModuleName)
           break;
@@ -859,14 +859,14 @@
                              /*ShouldCloneClient=*/true);
 
-  // Note that this module is part of the module build path, so that we
+  // Note that this module is part of the module build stack, so that we
   // can detect cycles in the module graph.
   Instance.createFileManager(); // FIXME: Adopt file manager from importer?